.. _data_library_ref:

:mod:`biolearn.data_library`: DataLibrary
==========================================

.. automodule:: biolearn.data_library
   :no-members:
   :no-inherited-members:

**Classes**:

.. currentmodule:: biolearn.data_library

.. autosummary::
   :toctree: generated/
   :template: class.rst

   DataLibrary
   DataSource
   GeoData